pub trait ConditionalFormattingExt {
// Required methods
fn cell_range(&self) -> Option<&str>;
fn rules(&self) -> &[ConditionalRule];
fn rule_count(&self) -> usize;
}Expand description
Extension methods for types::ConditionalFormatting.
Provides convenient access to cell range and contained rules.
Gated on the sml-styling feature.
ECMA-376 Part 1, Section 18.3.1.18 (conditionalFormatting).
Required Methods
Sourcefn cell_range(&self) -> Option<&str>
fn cell_range(&self) -> Option<&str>
Get the cell range this formatting applies to (sqref attribute).
For example, "A1:B10" or "A1:A10 C1:C10" (space-separated ranges).
Sourcefn rules(&self) -> &[ConditionalRule]
fn rules(&self) -> &[ConditionalRule]
Get the conditional formatting rules.
Sourcefn rule_count(&self) -> usize
fn rule_count(&self) -> usize
Get the number of rules.
Implementors
impl ConditionalFormattingExt for ConditionalFormatting
Available on crate feature
sml-styling only.